@@ -1,11 +1,12 @@
-## ----setup, echo = FALSE-------------------------------------------------
+## ----setup, echo = FALSE------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 );
 require('magrittr', quiet=TRUE);
+require('webshot', quiet=TRUE);
 
-## ----raa, echo=FALSE, fig.width=6, fig.height=3.5, fig.cap="Figuur 1: De reasoned action approach."----
+## ----raa, echo=FALSE, fig.width=3, fig.height=2, fig.cap="Figuur 1: De reasoned action approach."----
 
 raaGraph <-
   DiagrammeR::create_graph() %>%
@@ -25,10 +26,24 @@ raaGraph <-
                                     c("dir", "forward", "edge"),
                                     c("fillcolor", "#FFFFFF", "node"));
 
-DiagrammeR::render_graph(raaGraph);
+if (knitr::is_latex_output()) {
+  ### From DiagrammeR::export_graph
+  dot_code <- DiagrammeR::generate_dot(raaGraph);
+  graphSvg <-
+    DiagrammeRsvg::export_svg(DiagrammeR::grViz(dot_code));
+  graphSvg <-
+    sub(".*\n<svg ", "<svg ", graphSvg);
+  graphSvg <- gsub('<svg width=\"[0-9]+pt\" height=\"[0-9]+pt\"\n viewBox=',
+                   '<svg width="2000px" height="1000px" viewBox=',
+                   graphSvg);
+  grid::grid.newpage();
+  grid::grid.raster(png::readPNG(rsvg::rsvg_png(charToRaw(graphSvg))));
+} else if (knitr::is_html_output()) {
+  DiagrammeR::render_graph(raaGraph);
+}
 
 
-## ----abcd-specificatie, echo=FALSE---------------------------------------
+## ----abcd-specificatie, echo=FALSE, warning=FALSE, results="asis"-------------
 abcd_specs_dutch_xtc <- behaviorchange::abcd_specs_dutch_xtc;
 
 names(abcd_specs_dutch_xtc) <-
@@ -40,9 +55,35 @@ names(abcd_specs_dutch_xtc) <-
     "Sub-gedragingen",
     "Doelgedrag");
 
-knitr::kable(abcd_specs_dutch_xtc);
+if (knitr::is_latex_output()) {
+  cat("\n
+\\newpage\n
+\\blandscape\n
+\n
+");
 
-## ----abcd-diagram, echo=FALSE, fig.width=14, fig.height=7, eval=FALSE----
+  print(
+    kableExtra::kable_styling(kableExtra::column_spec(
+      knitr::kable(abcd_specs_dutch_xtc,
+                   caption="Een voorbeeld van een ABCD matrix.",
+                   booktabs = TRUE,
+                   row.names = FALSE,
+                   longtable = TRUE),
+    column = 1:7,
+    width = c("2.5cm", "5cm", "4cm",
+              "3.5cm", "2cm", "2.5cm", "1.8cm")
+    )));
+
+  cat("\n
+\\elandscape\n
+\\newpage\n
+\n
+");
+} else {
+  knitr::kable(abcd_specs_dutch_xtc);
+}
+
+## ----abcd-diagram, echo=FALSE, fig.width=14, fig.height=7, eval=FALSE---------
 #  abcd_specs_dutch_xtc_graph <-
 #    behaviorchange::abcd(behaviorchange::abcd_specs_dutch_xtc);
 #  print(abcd_specs_dutch_xtc_graph);
